==> 6.9.5.tar.gz: lib/XWidgets/XTextFormField/XTextFormField.dart <==
part of xwidgetbase;

class XTextFormField extends StatelessWidget {
  final String? label;
  final String hintText;
  final ValueChanged<String>? onChanged;
  final TextInputType keyboardType;

  ///Settalo per gestire l'uscita dal campo
  final Function(String?)? onFieldSubmitted;
  final Function(String?)? onSaved;

  ///Settalo gestire l'onPressed del botton di salvataggio in basso a destra del Campo solo se TRUE isVisibleBTNsave
  final Function? onPressedBTNSave;
  final Function? validator;
  final Function? onEditingComplete;
  final FocusNode? focusNode;
  final bool showText;
  final bool multiLines;
  final bool isVisibleBTNsave;
  final double? width;
  final int? maxLines;
  final double? height;
  final TextInputAction textInputAction;
  final TextEditingController? controller;
  final AutovalidateMode? autovalidateMode;
  final String? initialValue;
  final TextStyle? labelStyle;
  GestureTapCallback? onTap;
  final List<String>? ddItems;
  List<TextInputFormatter>? inputFormatters;
  final Color? textColor;
  final FloatingLabelBehavior? floatingLabelBehaviorActive;
  final InputBorder? border;
  final InputBorder? disabledBorder;
  final InputBorder? enabledBorder;
  final InputBorder? focusedBorder;
  final TextStyle? hintStyle;
  final EdgeInsetsGeometry? contentPadding;
  final Widget? suffixIcon;
  final bool? isDenseTextFormField;
  final Color? colorBorder;
  final int? maxLenght;
  final Color? focusColor;
  final Color? fillColor;
  final bool autoFocus;
  final bool borderVisible;
  final TextCapitalization textCapitalization;
  final Widget? counter;
  XTextFormField(
      {this.label,
      this.hintText = 'inserisci..',
      this.focusColor,
      this.fillColor,
      this.focusedBorder,
      this.colorBorder,
      this.borderVisible = true,
      this.border,
      this.suffixIcon,
      this.textCapitalization = TextCapitalization.none,
      this.contentPadding,
      this.isDenseTextFormField = true,
      this.enabledBorder,
      this.disabledBorder,
      this.floatingLabelBehaviorActive,
      this.hintStyle,
      this.labelStyle,
      this.onEditingComplete,
      this.initialValue,
      this.ddItems,
      this.inputFormatters,
      this.isVisibleBTNsave = false,
      this.controller,
      this.onPressedBTNSave,
      this.width,
      this.textColor,
      this.onTap,
      this.maxLines,
      this.height = 40,
      this.onChanged,
      this.multiLines = false,
      this.keyboardType = TextInputType.text,
      this.textInputAction = TextInputAction.next,
      this.onFieldSubmitted,
      this.onSaved,
      this.validator,
      this.counter,
      this.focusNode,
      this.autovalidateMode,
      this.maxLenght,
      this.autoFocus = false,
      this.showText = false});

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Stack(
        alignment: Alignment.bottomRight,
        children: <Widget>[
          Column(children: <Widget>[
            Container(
              width: width,
              height: height,
              child: TextFormField(
                  autofocus: autoFocus,
                  initialValue: initialValue,
                  controller: controller,
                  onTap: onTap,
                  focusNode: focusNode,
                  keyboardType: (multiLines ? TextInputType.multiline : keyboardType),
                  style: labelStyle ?? TextStyle(color: textColor ?? Colors.white),
                  textInputAction: (multiLines ? TextInputAction.newline : textInputAction),
                  onFieldSubmitted: onFieldSubmitted,
                  obscureText: showText,
                  // strutStyle: StrutStyle(height: height, fontSize: 18, forceStrutHeight: true),
                  onSaved: onSaved,
                  onEditingComplete: onEditingComplete as void Function()?,
                  onChanged: onChanged,
                  inputFormatters: inputFormatters ?? [],
                  maxLines: maxLines,
                  maxLength: maxLenght,
                  autovalidateMode: autovalidateMode,
                  validator: validator as String? Function(String?)?,
                  textCapitalization: textCapitalization,
                  decoration: InputDecoration(
                    isDense: isDenseTextFormField,
                    floatingLabelBehavior: floatingLabelBehaviorActive ?? FloatingLabelBehavior.always,
                    contentPadding: contentPadding ?? EdgeInsets.only(top: 20, left: 5, bottom: 1),
                    border: borderVisible == true ? border ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    disabledBorder: borderVisible == true ? disabledBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    enabledBorder: borderVisible == true ? enabledBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    focusedBorder: borderVisible == true ? focusedBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    focusColor: focusColor ?? Colors.white,
                    counter: counter != null ? counter : null,
                    enabled: counter == null ? true : false,
                    fillColor: fillColor ?? Colors.white,
                    labelText: label,
                    suffixIcon: suffixIcon,
                    hintText: hintText,
                    labelStyle: labelStyle,
                    hintStyle: hintStyle ?? TextStyle(color: textColor ?? Colors.white),
                  )),
            ),
          ]),
          isVisibleBTNsave == true
              ? Container(
                  alignment: Alignment.bottomRight,
                  height: 40,
                  child: Row(mainAxisAlignment: MainAxisAlignment.end, crossAxisAlignment: CrossAxisAlignment.end, children: <Widget>[
                    Container(
                        padding: EdgeInsets.fromLTRB(0, 0, 0, 5),
                        child: ElevatedButton(
                            style: ElevatedButton.styleFrom(elevation: 1, primary: Colors.transparent),
                            onPressed: onPressedBTNSave as void Function()?,
                            child: Icon(
                              Icons.done,
                              color: Colors.greenAccent,
                            ))),
                    SizedBox(width: 5),
                  ]),
                )
              : Container()
        ],
      ),
    );
  }
}

==> 7.0.4.tar.gz: lib/XWidgets/XTextFormField/XTextFormField.dart <==
part of xwidgetbase;

class XTextFormField extends StatelessWidget {
  final String? label;
  final String hintText;
  final ValueChanged<String>? onChanged;
  final TextInputType keyboardType;

  ///Settalo per gestire l'uscita dal campo
  final Function(String?)? onFieldSubmitted;
  final Function(String?)? onSaved;

  ///Settalo gestire l'onPressed del botton di salvataggio in basso a destra del Campo solo se TRUE isVisibleBTNsave
  final Function? onPressedBTNSave;
  final String? Function(String?)? validator;
  final Function? onEditingComplete;
  final FocusNode? focusNode;
  final bool showText;
  final bool multiLines;
  final bool isVisibleBTNsave;
  final double? width;
  final int? maxLines;
  final double? height;
  final TextInputAction textInputAction;
  final TextEditingController? controller;
  final AutovalidateMode? autovalidateMode;
  final String? initialValue;
  final TextStyle? labelStyle;
  GestureTapCallback? onTap;
  final List<String>? ddItems;
  List<TextInputFormatter>? inputFormatters;
  final Color? textColor;
  final FloatingLabelBehavior? floatingLabelBehaviorActive;
  final InputBorder? border;
  final InputBorder? disabledBorder;
  final InputBorder? enabledBorder;
  final InputBorder? focusedBorder;
  final TextStyle? hintStyle;
  final TextStyle? textStyle;
  final EdgeInsetsGeometry? contentPadding;
  final Widget? suffixIcon;
  final bool? isDenseTextFormField;
  final Color? colorBorder;
  final int? maxLenght;
  final Color? focusColor;
  final Color? fillColor;
  final bool autoFocus;
  final bool borderVisible;
  final TextCapitalization textCapitalization;
  final Widget? counter;
  final double? borderWidth;
  XTextFormField(
      {this.label,
      this.hintText = 'inserisci..',
      this.focusColor,
      this.fillColor,
      this.borderWidth,
      this.focusedBorder,
      this.colorBorder,
      this.borderVisible = true,
      this.border,
      this.suffixIcon,
      this.textCapitalization = TextCapitalization.none,
      this.contentPadding,
      this.isDenseTextFormField = true,
      this.enabledBorder,
      this.disabledBorder,
      this.floatingLabelBehaviorActive,
      this.hintStyle,
      this.labelStyle,
      this.textStyle,
      this.onEditingComplete,
      this.initialValue,
      this.ddItems,
      this.inputFormatters,
      this.isVisibleBTNsave = false,
      this.controller,
      this.onPressedBTNSave,
      this.width,
      this.textColor,
      this.onTap,
      this.maxLines,
      this.height = 40,
      this.onChanged,
      this.multiLines = false,
      this.keyboardType = TextInputType.text,
      this.textInputAction = TextInputAction.next,
      this.onFieldSubmitted,
      this.onSaved,
      this.validator,
      this.counter,
      this.focusNode,
      this.autovalidateMode,
      this.maxLenght,
      this.autoFocus = false,
      this.showText = false});

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Stack(
        alignment: Alignment.bottomRight,
        children: <Widget>[
          Column(children: <Widget>[
            Container(
              width: width,
              height: height,
              child: TextFormField(
                  autofocus: autoFocus,
                  initialValue: initialValue,
                  controller: controller,
                  onTap: onTap,
                  focusNode: focusNode,
                  keyboardType: (multiLines ? TextInputType.multiline : keyboardType),
                  style: textStyle ?? labelStyle ?? TextStyle(color: textColor ?? Colors.white),
                  textInputAction: (multiLines ? TextInputAction.newline : textInputAction),
                  onFieldSubmitted: onFieldSubmitted,
                  obscureText: showText,
                  // strutStyle: StrutStyle(height: height, fontSize: 18, forceStrutHeight: true),
                  onSaved: onSaved,
                  onEditingComplete: onEditingComplete as void Function()?,
                  onChanged: onChanged,
                  inputFormatters: inputFormatters ?? [],
                  maxLines: maxLines,
                  maxLength: maxLenght,
                  autovalidateMode: autovalidateMode,
                  validator: validator,
                  textCapitalization: textCapitalization,
                  decoration: InputDecoration(
                    counter: counter,
                    isDense: isDenseTextFormField,
                    floatingLabelBehavior: floatingLabelBehaviorActive ?? FloatingLabelBehavior.always,
                    contentPadding: contentPadding ?? EdgeInsets.only(top: 20, left: 5, bottom: 1),
                    border: borderVisible == true ? border ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: borderWidth ?? 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    disabledBorder: borderVisible == true ? disabledBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: borderWidth ?? 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    enabledBorder: borderVisible == true ? enabledBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: borderWidth ?? 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    focusedBorder: borderVisible == true ? focusedBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: borderWidth ?? 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    focusColor: focusColor ?? Colors.white,
                    fillColor: fillColor ?? Colors.white,
                    labelText: label,
                    suffixIcon: suffixIcon,
                    hintText: hintText,
                    labelStyle: labelStyle,
                    hintStyle: hintStyle ?? TextStyle(color: textColor ?? Colors.white),
                  )),
            ),
          ]),
          isVisibleBTNsave == true
              ? Container(
                  alignment: Alignment.bottomRight,
                  height: 40,
                  child: Row(mainAxisAlignment: MainAxisAlignment.end, crossAxisAlignment: CrossAxisAlignment.end, children: <Widget>[
                    Container(
                        padding: EdgeInsets.fromLTRB(0, 0, 0, 5),
                        child: ElevatedButton(
                            style: ElevatedButton.styleFrom(elevation: 1, primary: Colors.transparent),
                            onPressed: onPressedBTNSave as void Function()?,
                            child: Icon(
                              Icons.done,
                              color: Colors.greenAccent,
                            ))),
                    SizedBox(width: 5),
                  ]),
                )
              : Container()
        ],
      ),
    );
  }
}
